@@ -4,7 +4,7 @@
 # if you have many models here with many references from one model to another this may
 # raise a RecursionError
 # to avoid this, import only the models that you directly need like:
-# from from identitylib.card_client.model.pet import Pet
+# from identitylib.card_client.model.pet import Pet
 # or import this package, but before doing it, use:
 # import sys
 # sys.setrecursionlimit(n)
@@ -29,7 +29,9 @@ from identitylib.card_client.model.v1beta1_available_barcodes_create_request imp
 from identitylib.card_client.model.v1beta1_available_barcodes_list200_response import V1beta1AvailableBarcodesList200Response
 from identitylib.card_client.model.v1beta1_card_logos_list200_response import V1beta1CardLogosList200Response
 from identitylib.card_client.model.v1beta1_card_notes_create_request import V1beta1CardNotesCreateRequest
+from identitylib.card_client.model.v1beta1_card_notes_delete200_response import V1beta1CardNotesDelete200Response
 from identitylib.card_client.model.v1beta1_card_notes_delete_request import V1beta1CardNotesDeleteRequest
+from identitylib.card_client.model.v1beta1_card_notes_list200_response import V1beta1CardNotesList200Response
 from identitylib.card_client.model.v1beta1_card_requests_bulk_update200_response import V1beta1CardRequestsBulkUpdate200Response
 from identitylib.card_client.model.v1beta1_card_requests_bulk_update200_response_details_inner import V1beta1CardRequestsBulkUpdate200ResponseDetailsInner
 from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request import V1beta1CardRequestsBulkUpdateRequest
@@ -43,6 +45,6 @@ from identitylib.card_client.model.v1beta1_card_rfid_data_config_list200_respons
 from identitylib.card_client.model.v1beta1_card_rfid_data_config_list200_response_results_inner import V1beta1CardRfidDataConfigList200ResponseResultsInner
 from identitylib.card_client.model.v1beta1_cards_filter_request import V1beta1CardsFilterRequest
 from identitylib.card_client.model.v1beta1_cards_list200_response import V1beta1CardsList200Response
-from identitylib.card_client.model.v1beta1_cards_update200_response import V1beta1CardsUpdate200Response
 from identitylib.card_client.model.v1beta1_cards_update_request import V1beta1CardsUpdateRequest
+from identitylib.card_client.model.v1beta1_college_institution_ids_list200_response import V1beta1CollegeInstitutionIdsList200Response
 from identitylib.card_client.model.validation_error import ValidationError
